camelot.camelot.model.authentication.EmployerEmployee.EmployeeAdmin

Package camelot :: Package camelot :: Package model :: Module authentication :: Class EmployerEmployee :: Class EmployeeAdmin |
[hide private]
[frames] | no frames]

# Class EmployeeAdmin

source code

Instance Methods | [hide private]
Inherited from `view.elixir_admin.EntityAdmin`: `__init__`, `__str__`, `createFormView`, `createNewView`, `createSelectView`, `createTableView`, `createValidator`, `getColumns`, `getFieldAttributes`, `getFields`, `getFilters`, `getForm`, `getFormActions`, `getListCharts`, `getModelThread`, `getName`, `getRelatedEntityAdmin`, `getSubclasses`, `setDefaults` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Variables | [hide private]
| name = `'Employees'`
| list_display = `['established_to', 'from_date', 'thru_date']`
| fields = `['established_to', 'comment', 'from_date', 'thru_date']`
| field_attributes = `{'established_to': {'name': 'Name'}}`
Inherited from `view.elixir_admin.EntityAdmin`: `form`, `form_actions`, `form_display`, `form_size`, `form_title_column`, `list_actions`, `list_charts`, `list_filter`, `list_size`

Properties | [hide private]
Inherited from `object`: `__class__`